<template>
  <div class="bot" v-if="showfield">
    <div class="top1">
      <span class="botcon">
        <span class="icon"></span>
        <span class="text">场强覆盖评估</span>
      </span>
      <span class="close" @click="close">x</span>
    </div>
    <div class="next">
      <el-form ref="form" :model="form" label-width="220px">
        <el-form-item label="传播模型:" prop="name">
          <el-select v-model="form.name" placeholder="请选择活动区域">
            <el-option
              label="ITU-R P.452模型(100MHz-50GHz)"
              value="ITU-R P.452模型(100MHz-50GHz)"
            ></el-option>
            <el-option
              label="ITU-R P.1546 模型(30MHz-3GHz)"
              value="ITU-R P.1546 模型(30MHz-3GHz)"
            ></el-option>
            <el-option label="自动匹配" value="自动匹配"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="接收高度:">
          <el-input v-model="form.height"
            ><i slot="suffix" style="margin-right: 10px; font-size: 35px"
              >M</i
            ></el-input
          >
        </el-form-item>
        <el-form-item label="覆盖半径:">
          <el-input v-model="form.radius"
            ><i slot="suffix" style="margin-right: 10px; font-size: 35px"
              >Km</i
            ></el-input
          >
        </el-form-item>
      </el-form>
      <div class="btns">
        <span @click="reset">重置</span>
        <span @click="analysis">分析</span>
      </div>
    </div>
    <div class="showpic" v-if="showpic">
      <div :style="innerbac" @click="openDia"></div>
    </div>
    <changePic @colordata="getdata" />
  </div>
</template>

<script>
let handler, divPoint3;
import {
  intensity,
  getbounds,
  createPic,
  picurl,
  showCQ,
} from "../../api/http";
import bus from "../../utils/bus";

import changePic from "../common/color.vue";
let Base64 = require("js-base64").Base64;
export default {
  components: {
    changePic,
  },
  data() {
    return {
      form: {
        name: "ITU-R P.1546 模型(30MHz-3GHz)",
        height: 10,
        radius: 10,
      },
      nowplay: "",
      showfield: false,
      imageid: null,
      showpic: false,
      startshow: false,
      colorContainer: {},
      innerbac: {
        width: "30%",
        height: "70%",
        border: "1px solid #000",
        transform: "translate(40px,90px)",
        backgroundImage:
          "url(" + require("@/assets/image/botbtn/color.png") + ")",
        backgroundPosition: "center",
        backgroundSize: ` 100% 100%`,
      },
    };
  },
  mounted() {
    bus.$on("showdio", (e) => {
      this.showfield = e == 5;
    });
    bus.$on("clearEve", (e) => {
      this.reset();
    });
  },
  methods: {
    getdata(data) {
      this.colorContainer = data;
    },
    openDia() {
      bus.$emit("changeColor", true);
    },
    close() {
      this.showfield = false;
    },
    analysis() {
      this.reset();
      window.showtable = true;
      window.nowAnalyze = true;
      window.allowClick = true;
      if (this.imageid) {
        window.layers.remove(window.layers.get(this.imageid));
        this.imageid = null;
      }
      //点击获取信息
      handler ? handler.destroy() : "";
      handler = new Cesium.ScreenSpaceEventHandler(window.Viewer.scene.canvas);
      var that = this;
      handler.setInputAction(function (movement) {
        // 全局变量作用是控制掌控当前是否为可分析状态
        var pick = window.Viewer.scene.pick(movement.position);
        if (Cesium.defined(pick) && pick.id && pick.id.properties) {
          if (!window.nowAnalyze) {
            return;
          }
          let data = {
            corverageType: 1,
            coverageRedius_km: that.form.radius,
            coverageThreshold: -100,
            model: "2",
            noiseTemp: 293,
            rxAntGain_dBi: that.form.height,
            rxAntHeight: that.form.height,
            station: pick.id.properties.guid.getValue(),
            type: "1",
          };
          const loading = that.$loading({
            lock: true,
            text: "计算中",
            spinner: "el-icon-loading",
            background: "rgba(0, 0, 0, 0.7)",
          });
          intensity(data)
            .then((res) => {
              if (res.message === "Success") {
                getbounds({ file: Base64.encode(res.data) }).then((res1) => {
                  if (res1.message === "Success") {
                    let points = res1.data.points;
                    let data = {
                      colorSchemes: 1,
                      file: Base64.encode(res.data),
                      maxColor: "FF0000",
                      maxValue: 100,
                      minColor: "0000FF",
                      minValue: 0,
                    };
                    that.nowplay = Base64.encode(res.data);
                    data = { ...data, ...that.colorContainer };
                    createPic(data).then((res2) => {
                      if (res2.message === "Success") {
                        let rectangle = sgworld.Creator.addSimpleGraphic(
                          "rectangle",
                          {
                            removeEdit: true,
                            coordinates: Cesium.Rectangle.fromDegrees(
                              points[0].x,
                              points[0].y,
                              points[1].x,
                              points[1].y
                            ),
                            color: "rgba(255,255,255,0.5)",
                            image:
                              "http://221.224.53.36:9081/calc/picurl?file=" +
                              Base64.encode(res2.data),
                          }
                        );
                        if (that.imageid) {
                          window.Viewer.entities.removeById(that.imageid);
                          that.imageid = null;
                        }
                        that.imageid = rectangle.id;

                        loading.close();
                        that.$message({
                          message: "计算成功",
                          type: "success",
                        });
                        that.showpic = true;
                        that.startshow = true;
                        window.showtable = false;
                        window.nowAnalyze = false;
                      }
                    });
                  }
                });
              }
            })
            .catch((error) => {
              loading.close();
            });
        } else {
          if (Cesium.defined(pick) && pick.id && pick.id.properties) {
            return;
          }
          let obj = {
            analysisAction: "-1",
            analysisType: "2", //这个值可能和列表选择有关  目前锁定地址的
            filename: that.nowplay,
          };
          let position = sgworld.Navigate.getMouseDegrees(movement.position);
          obj.lat = position.lat;
          obj.lng = position.lon;
          if (that.startshow) {
            showCQ(obj).then((res) => {
              let data = res.data;
              if (divPoint3) {
                divPoint3.deleteObject();
                divPoint3 = null;
              }
              if (data != "无数据") {
                divPoint3 = sgworld.Creator.createDivPoint(
                  "合肥",
                  { lon: obj.lng, lat: obj.lat },
                  {
                    type: "custom",
                    offset: ["c", 60],
                    description: `
              <div class="divPoint-custom">
                <p>${data}</p>
              </div>
              `,
                    near: 0,
                    far: 100000,
                  }
                );
              }
            });
          }
        }
      }, Cesium.ScreenSpaceEventType.LEFT_CLICK);
    },
    reset() {
      try {
        window.Viewer.entities.removeById(this.imageid);
        this.startshow = false;
        divPoint3.deleteObject();
        divPoint3 = null;
        this.imageid = null;
        handler.destroy(); //关闭事件句柄
        handler = null;
      } catch (error) {}
    },
  },
  watch: {
    colorContainer: {
      deep: true,
      handler(data) {
        let colornow = {
          width: "30%",
          height: "70%",
          border: "1px solid #000",
          transform: "translate(40px,90px)",
          backgroundImage: `linear-gradient(${data.maxColor},${data.minColor})`,
        };
        this.innerbac = colornow;
      },
    },
  },
};
</script>

<style scoped>
.bot {
  width: 1000px;
  height: 1150px;
  background: url(~@/assets/image/test/22.png);
  background-size: 100% 100%;
  background-repeat: no-repeat;
  position: absolute;
  left: 3920px;
  top: 680px;
}
.top1 {
  width: 96%;
  height: 11%;
  font-size: 45px;
  font-weight: bold;
  margin: 0px auto;
  border-bottom: 2px solid #fff;
  color: #fff;
  letter-spacing: 3px;
}
.icon {
  position: absolute;
  left: 73px;
  width: 50px;
  height: 50px;
  top: 39px;
  background-size: 100% 100% !important;
  background-repeat: no-repeat !important;
  background-position: center !important;
  background: url(~@/assets/image/subject/题标.png);
}
.text {
  display: inline-block;
  margin-left: 110px;
}
.next >>> .el-select {
  width: 670px;
}
.close {
  position: absolute;
  font-size: 45px;
  font-weight: 400;
  right: 60px;
  top: 25px;
}
.close:hover {
  color: red;
  transition: color 1s;
  cursor: pointer;
}
.next {
  width: 89%;
  height: 79%;
  margin: 120px auto;
}
.next >>> .el-form-item {
  margin-top: 100px;
}
.next >>> .el-input {
  width: 84%;
}
.next >>> .el-date-editor {
  width: 390px;
}
.next >>> .el-form-item__label {
  color: #fff;
  font-size: 40px;
}
.next >>> .el-input__inner {
  font-size: 30px;
}
.next >>> .el-form-item__error {
  font-size: 30px;
  font-weight: 700;
}
.botcon {
  display: inline-block;
  margin-top: 34px;
}
.btns {
  margin-top: 130px;
  width: 100%;
  height: 70px;
  transform: translateX(-0px);
  display: flex;
  justify-content: center;
}
.btns > span {
  display: block;
  width: 200px;
  height: 70px;
  margin: 0 40px;
  border: 1px solid #000;
  text-align: center;
  font-size: 35px;
  line-height: 70px;
  cursor: pointer;
}
.btns > span:nth-child(3) {
  color: #fff;
  background-image: linear-gradient(#76c2f6, #6a9cf1);
}
.btns > span:nth-child(-n + 2) {
  color: #000;
  background: #cadaea;
}
.showpic {
  width: 260px;
  height: 400px;
  background: url(~@/assets/image/botbtn/bac.png);
  background-position: center;
  background-size: 100% 100%;
  position: absolute;
  top: 1200px;
  right: 50px;
}
</style>
